pub fn parse_encryption_header(data: &[u8]) -> Result<(EncryptionHeader, &[u8])>Expand description
Parse an encryption header from the data following the E mode byte.
Returns the parsed header and a slice of the remaining encrypted payload.
pub fn parse_encryption_header(data: &[u8]) -> Result<(EncryptionHeader, &[u8])>Parse an encryption header from the data following the E mode byte.
Returns the parsed header and a slice of the remaining encrypted payload.